#
# spec file for package python-CouchDB
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-CouchDB
Version:        1.0
Release:        5.6
Url:            https://github.com/djc/couchdb-python/
Summary:        A Python library for working with CouchDB
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/C/CouchDB/CouchDB-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-Sphinx
BuildRequires:  python-devel
Suggests:       couchdb
Provides:       python-couchdb = %{version}
Obsoletes:      python-couchdb < %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
This is a Python library for the CouchDB document-oriented database. It
provides a convenient high level interface for the CouchDB server.

%package doc
Summary:        The  API reference files for CouchDB 
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description doc
This is a Python library for the CouchDB document-oriented database. It
provides a convenient high level interface for the CouchDB server.

This package contains documentation for python-couchdb.

%prep
%setup -q -n CouchDB-%{version}
sed -i "1d" couchdb/{view,http,tests/couch_tests,tools/replicate,tools/load,tools/dump}.py # Fix non-executable scripts

%build
python setup.py build
mkdir doc/build && make doc && rm -rf doc/build/html/.buildinfo # Build HTML documentation

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc ChangeLog.rst COPYING README.rst
%{_bindir}/couch*
%{python_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc doc/build/*

%changelog
* Sat May  2 2015 benoit.monin@gmx.fr
- update to version 1.0:
  * Many smaller Python 3 compatibility issues have been fixed
  * Improve handling of binary attachments in the couchdb-dump tool
  * Added testing via tox and support for Travis CI
- additional changes from version 0.10:
  * Now compatible with Python 2.7, 3.3 and 3.4
  * Added batch processing for the couchdb-dump tool
  * A very basic API to access the _security object
  * A way to access the update_seq value on view results
- update project URL
- change documentation files from txt to rst, to follow upstream
* Wed Sep 25 2013 p.drouand@gmail.com
- Update to version 0.9
  * Don't validate database names on the client side. This means some methods
    dealing with database names can return different exceptions than before.
  * Use HTTP socket more efficiently to avoid the Nagle algorithm, greatly
    improving performace. Note: add the `{nodelay, true}` option to the CouchDB
    server's httpd/socket_options config.
  * Add support for show and list functions.
  * Add support for calling update handlers.
  * Add support for purging documents.
  * Add `iterview()` for more efficient iteration over large view results.
  * Add view cleanup API.
  * Enhance `Server.stats()` to optionally retrieve a single set of statistics.
  * Implement `Session` timeouts.
  * Add `error` property to `Row` objects.
  * Add `default=None` arg to `mapping.Document.get()` to make it a little more
    dict-like.
  * Enhance `Database.info()` so it can also be used to get info for a design
    doc.
  * Add view definition options, e.g. collation.
  * Fix support for authentication in dump/load tools.
  * Support non-ASCII document IDs in serialization format.
  * Protect `ResponseBody` from being iterated/closed multiple times.
  * Rename iteration method for ResponseBody chunks to `iterchunks()` to
    prevent usage for non-chunked responses.
  * JSON encoding exceptions are no longer masked, resulting in better error
    messages.
  * `cjson` support is now deprecated.
  * Fix `Row.value` and `Row.__repr__` to never raise exceptions.
  * Fix Python view server's reduce to handle empty map results list.
  * Use locale-independent timestamp identifiers for HTTP cache.
  * Don't require setuptools/distribute to install the core package. (Still
    needed to install the console scripts.)
* Tue Mar 27 2012 saschpe@suse.de
- Simplify macro usage
- Fix doc package requires on base package
- Only suggest couchdb, it may reside on a different machine
* Tue Sep 20 2011 cfarrell@suse.com
- license update: BSD-3-Clause
  SPDX syntax (http://www.spdx.org/licenses)
* Tue Sep 20 2011 saschpe@suse.de
- Renamed to python-CouchDB
- Require couchdb at runtime
- Drop python-couchdb-shebang.patch and fix it in the spec file directly
* Mon Oct 11 2010 coolo@novell.com
- update to 0.8
  * The couchdb-replicate script has changed from being a poor man's version of
  continuous replication (predating it) to being a simple script to help
  kick off replication jobs across databases and servers.
  * Reinclude all http exception types in the 'couchdb' package's scope.
  * Request retries schedule and frequency are now customizable.
  * Allow more kinds of request errors to trigger a retry.
  * Breaking change: the dependency on `httplib2` has been replaced by
  an internal `couchdb.http` library. This changes the API in several places.
  Most importantly, `resource.request()` now returns a 3-member tuple.
  * Breaking change: `couchdb.schema` has been renamed to `couchdb.mapping`.
  This better reflects what is actually provided. Classes inside
  `couchdb.mapping` have been similarly renamed (e.g. `Schema` -> `Mapping`).
  * Breaking change: `couchdb.schema.View` has been renamed to
  `couchdb.mapping.ViewField`, in order to help distinguish it from
  `couchdb.client.View`.
  * Breaking change: the `client.Server` properties `version` and `config`
  have become methods in order to improve API consistency.
* Wed Apr 14 2010 jfunk@funktronics.ca
- Remove version in dependency for doc subpackage
- Remove buildroot removal in install
* Mon Mar 29 2010 jfunk@funktronics.ca
- Clean up
- Rename devel subpackage to doc, since it only contains docs
- Build as noarch
- Remove unneeded dependency on couchdb server
* Tue Mar  9 2010 aj@suse.de
- Fix Group.
- Fix building on x86-64.
* Mon Feb 15 2010 awafaa@opensuse.org
- Initial build for openSUSE 0.6.1
